import { AngularFireStorage } from 'angularfire2/storage';
import { OnInit, OnDestroy, EventEmitter } from '@angular/core';
import { FileStoreRecord } from './file-store.record';
import { FileStoreConfig } from './file-store.config';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/takeUntil';
/**
 * File Drag & Drop Component
 */
export declare class FileDndComponent implements OnInit, OnDestroy {
    private storage;
    /**
     * FileStoreConfig object
     */
    config: FileStoreConfig;
    /**
     * By default developmentMode is false
     * Set this to true to observe log outputs on console
     */
    developmentMode?: boolean;
    /**
     * Output event onUpload($event:FileStoreRecord[]) emitted upon completion of upload task(s)
     */
    onUpload: EventEmitter<FileStoreRecord[]>;
    uploadButtonName: string;
    dropzoneActive: boolean;
    successFeedback: string;
    errorFeedback: string;
    targetFileList: Array<{
        file: File;
        progress: Observable<number> | null;
    }>;
    private uploadButtonPushCount;
    private fileStoreRecords;
    private uploadMetadata;
    private unsubscribe;
    constructor(storage: AngularFireStorage);
    /**
     * Initialize with defaults and throw error for any missing require configuration
     */
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * Update dropzoneActive when Dragged & Hovered
     * @param  boolean value based on the Drag Hover
     */
    dropzoneState($event: boolean): void;
    /**
     * Upon drop event, upload the files in the FileList
     * @param fileList List of Files to upload
     */
    handleDrop(fileList: FileList): void;
    /**
     * Upload the dropped target files in the list
     */
    upload(): void;
    /**
     * Clear the current list of files for upload
     */
    clear(): void;
    /**
     * Set success feedback on the view upon completion of all uploads
     */
    private uploadComplete();
    /**
     * Log the outputs to console when developmentMode is true
     * @param msg Message text to log
     * @param optionalParams any additional parameters / objects to log along with the message
     */
    private consoleLog(msg?, ...optionalParams);
}
